# Security Policy

## Supported Versions

Security updates are applied only to the most recent releases.

## Reporting a Vulnerability

 - :x: **If you think you have found a security vulnerability, please DO NOT disclose it publicly until we’ve had a chance to fix it**
 - :x: Please DO NOT report security vulnerabilities using GitHub issues
 - :white_check_mark: To report a security issue, email jussiva@gmail.com and include the word "SECURITY" in the subject line.
 
